/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * This scene is designed for 16:9 aspect ratio.                                                                   * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#version 3.7;

#local UseRadiosity = yes;

#local StartFontVariationNumber = 0; //0, 20, 40, 60, etc. - Set this variable to render different sample styles.

global_settings {
   assumed_gamma 2.2
   charset utf8
   max_trace_level 20
   #if (UseRadiosity)
      radiosity {
         pretrace_start .08
         pretrace_end .004
         count 600
         error_bound .002
         recursion_limit 2
         normal on
      } //radiosity
   #end //#if
} //global_settings

#include "colors.inc"
#include "BorderChars.inc"

#local CameraX = 0;
#local CameraY = 0;
#local CameraZ = 5.5;

camera {
   location <CameraX, CameraY, -CameraZ>
   direction <0, 0, 1>
   right (3840/2160) * x
   rotate -60 * x
   look_at <CameraX, CameraY - 1.5, 0>
} //camera

#if (UseRadiosity)
   #local Dome = object {
      difference {
         sphere {0, 20001}
         sphere {0, 20000}
      } //difference
      texture {
         pigment {
            gradient z
            color_map {
               [0, 1 color White * 2.21 color White * .6]
            } //color_map
         } //pigment
         finish {emission 1 diffuse 0}
         scale <1, 1, 20000>
      } //texture
      no_reflection
   } //object
   object {Dome}
#else
   light_source {<60, 80, -200> color White * 1.65 shadowless}
#end //#if

#local TextColor_Outer = texture {pigment {color White}}

#local TextColor_Inner = texture {
   #local Color0 = color <0.0000, 0.8894, 0.7535>;
   #local Color1 = color <0.6341, 0.0124, 0.8235>;
   pigment {
      gradient y
      color_map {
         [0 color Color0]
         [.4 color (Color0 * 75 + Color1 * 25) / 100]
         [.6 (Color0 + Color1) / 2]
         [1 color Color1]
      } //color_map
   } //pigment
   finish {emission .1}
   #local YScaleAdd_Bottom = .75 / 2 * .95; //Height of the bottom of the "g"
   #local YScaleAdd_Top = .075; //Height of the top of the "*"
   scale <1, 1 + YScaleAdd_Bottom + YScaleAdd_Top, 1>
   translate -YScaleAdd_Bottom * y
} //texture

#local TextColor_Back = texture {pigment {color Black}}

#local BackgroundColor = texture {
   pigment {checker color <0.9000, 0.8659, 0.8153> color <0.9639, 0.9419, 0.9021>}
   #local S = 1.5;
   scale <S, S, 1>
} //texture

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * THE SCENE                                                                                                       * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#local LeftMargin = -2.25;
#local TopMargin = 1;
#local ZOffset = -.1;

#local TextScale = 1;
#local UseActualParagraphHeight = no;

#declare GAP_Width = .1;

#local DX = 1.5;
#local DY = DX;

#local Grid = object {
   union {
      #local FontVariationNumber = StartFontVariationNumber;
      #for (I, 0, 3)
         #for (J, 0, 5)
            #if (I < 2 | (J > 0 & J < 5))
               #local GridX = -DX + J * DX;
               #local GridY = -I * DY + 1;
               #switch (FontVariationNumber)
                  #case (0) //Plain
                     #local FontVariationNumber = 0;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (1) //Raised center (use when border and center are the same height)
                     #local FontVariationNumber = 1;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local BorderHeight = .025;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderHeight, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (2) //Lowered center
                     #local FontVariationNumber = 24;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local BorderDepth = .025;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (3) //Striped
                     #local FontVariationNumber = 3;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local StripeWidth = .02;
                     #local StripeHeight = 0;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, StripeWidth, StripeHeight, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (4) //Color gradient
                     #local FontVariationNumber = 4;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local StripeWidth = .04;
                     #local NSteps = 15;
                     #local ExtraParameter_Color0 = color <0.0000, 0.8894, 0.7535>;
                     #local ExtraParameter_Color1 = color <0.6341, 0.0124, 0.8235>;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, StripeWidth, NSteps, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (5) //Hollow stripe
                     #local FontVariationNumber = 5;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local StripeWidth = .02;
                     #local StripeDepth = .015;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, StripeWidth, StripeDepth, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (6) //Hollow inside
                     #local FontVariationNumber = 6;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (7) //Angled bevel
                     #local FontVariationNumber = 7;
                     #local TextDepth = .08;
                     #local BorderHeight = .05;
                     #local NSteps = 5;
                     SetFontStyle (0, FontVariationNumber, TextDepth, BorderHeight, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (8) //Rounded bevel
                     #local FontVariationNumber = 8;
                     #local TextDepth = .08;
                     #local BorderHeight = .05;
                     #local NSteps = 7;
                     SetFontStyle (0, FontVariationNumber, TextDepth, BorderHeight, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (9) //Solid hourglass (convex)
                     #local FontVariationNumber = 9;
                     #local TextDepth = .2;
                     #local EffectWidth = .04;
                     #local NSteps = 17;
                     SetFontStyle (0, FontVariationNumber, TextDepth, EffectWidth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (10) //Hollow hourglass (convex)
                     #local FontVariationNumber = 10;
                     #local TextDepth = .2;
                     #local EffectWidth = .04;
                     #local WallThickness = .02;
                     #local NSteps = 17;
                     SetFontStyle (0, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (11) //Solid hourglass (concave)
                     #local FontVariationNumber = 11;
                     #local TextDepth = .2;
                     #local EffectWidth = .04;
                     #local NSteps = 17;
                     SetFontStyle (0, FontVariationNumber, TextDepth, EffectWidth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (12) //Hollow hourglass (concave)
                     #local FontVariationNumber = 12;
                     #local TextDepth = .2;
                     #local EffectWidth = .04;
                     #local WallThickness = .02;
                     #local NSteps = 17;
                     SetFontStyle (0, FontVariationNumber, TextDepth, EffectWidth, WallThickness, NSteps, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (13) //Solid half-hourglass (concave)
                     #local FontVariationNumber = 13;
                     #local TextDepth = .08;
                     #local EffectWidth = .04;
                     #local NSteps = 9;
                     SetFontStyle (0, FontVariationNumber, TextDepth, EffectWidth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (14) //Hollow inside, bordered
                     #local FontVariationNumber = 14;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .02;
                     #local SolidWidth = .02;
                     #local BorderDepth = -.02;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, SolidWidth, BorderDepth, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (15) //Hollow stripe with raised center
                     #local FontVariationNumber = 15;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local StripeWidth = .02;
                     #local StripeDepth = .02;
                     #local InnerHeight = .03;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, StripeWidth, StripeDepth, InnerHeight, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (16) //Angled reverse bevel
                     #local FontVariationNumber = 16;
                     #local TextDepth = .2;
                     #local BorderDepth = .05;
                     #local NSteps = 5;
                     SetFontStyle (0, FontVariationNumber, TextDepth, BorderDepth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (17) //Rounded reverse bevel/concave
                     #local FontVariationNumber = 17;
                     #local TextDepth = .2;
                     #local BorderDepth = .05;
                     #local NSteps = 7;
                     SetFontStyle (0, FontVariationNumber, TextDepth, BorderDepth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (18) //Rounded reverse bevel/convex
                     #local FontVariationNumber = 18;
                     #local TextDepth = .2;
                     #local BorderDepth = .05;
                     #local NSteps = 7;
                     SetFontStyle (0, FontVariationNumber, TextDepth, BorderDepth, NSteps, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (19) //Stack
                     #local FontVariationNumber = 19;
                     #local TextDepth = .04;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local SpacerDepth = .015;
                     #local NSteps = 3;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, SpacerDepth, NSteps, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (20) //Raised inner border
                     #local FontVariationNumber = 20;
                     #local TextDepth = .04;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local RaisedBorderWidth = .03;
                     #local RaisedBorderHeight = .04;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, RaisedBorderWidth, RaisedBorderHeight, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (21) //Specular highlights
                     #local FontVariationNumber = 21;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local BorderDepth = .025;
                     #local Angle = 160;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, Angle, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (22) //Drop shadow
                     #local FontVariationNumber = 22;
                     #local TextDepth = .02;
                     #local InvisibleBorderWidth = 0;
                     #local Quadrant = 4; //1, 2, 3, or 4
                     #local XYOffset_Solid = .035;
                     #local XYOffset_Space = 0;
                     #local LeaveInOffsetPosition = yes; //Set to "yes" if used as drop shadows, set to "no" if used as stand-alone characters.
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, Quadrant, XYOffset_Solid, XYOffset_Space, LeaveInOffsetPosition, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (23) //Raised center version 2
                     #local FontVariationNumber = 23;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local BorderHeight = .025;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderHeight, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #case (24) //Lowered center version 2
                     #local FontVariationNumber = 2;
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     #local BorderWidth = .03;
                     #local BorderDepth = .025;
                     SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#case
                  #range (25, 999)
                     #local TextDepth = .08;
                     #local InvisibleBorderWidth = 0;
                     SetFontStyle (0, 0, TextDepth, InvisibleBorderWidth, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
                  #break //#range
               #end //#switch
               #local NLines = 1;
               InitializeVariables (NLines)
               #declare LineText [0] = "P";
               CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
               object {Paragraph translate <GridX - BorderCharacterWidth [15] / 2, GridY, 0>}
               #local FontVariationNumber = FontVariationNumber + 1;
            #end //#if
         #end //#for
      #end //#for
      #local TextDepth = .04;
      #local InvisibleBorderWidth = .025;
      SetFontStyle (0, 0, TextDepth, InvisibleBorderWidth, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)
      #local FontVariationNumber = StartFontVariationNumber;
      #for (I, 0, 3)
         #for (J, 0, 5)
            #if (I < 2 | (J > 0 & J < 5))
               #local GridX = -DX + J * DX;
               #local GridY = -I * DY + .3;
               #local NLines = 1;
               InitializeVariables (NLines)
               #declare LineText [0] = str (FontVariationNumber, 0, 0);
               CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
               object {Paragraph scale <.3, .3, 1> translate <GridX + .05, GridY, 0>}
               #local FontVariationNumber = FontVariationNumber + 1;
            #end //#if
         #end //#for
      #end //#for
   } //union
} //object

#local Background = object {
   plane {
      z, 0 inverse
      texture {BackgroundColor translate <LeftMargin - S / 2, DY / 2 + .2, 0>}
   } //plane
} //object

object {Grid translate <LeftMargin, TopMargin, ZOffset>}

object {Background}
